import { useData } from './useData';
import { AxisBottom, AxisLeft } from './Axes';
import { Marks } from './Marks';
import { scaleLinear, format, extent} from 'd3';

const width = 960;
const height = 500;
const margin = { top: 50, right: 30, bottom: 65, left: 90 };

const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

export const ConnectedScatterPlot = () => {
  
  let data = useData();
  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');
  
  const xValue = d => d.Time;

  const xAxisLabel = 'Time';
  const yValue = d => d.Value;
  const yAxisLabel = 'Value';
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight]);
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        /* X-Axis */
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={5}
        />      
         <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>        
        /* X-Axis */
        /* Y-Axis */       
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight /
            2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
       /* Y-Axis */  
       /* data points */
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={7}
        />
       /* data points */
      </g>
    </svg>
  );
};
